@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.6.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.6.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -62,7 +62,7 @@
 
 
 /* Copy the first part of user declarations.  */
-/* Line 336 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 14 "../../cmd/tools/gmlparse.y"
 
 #include <stdlib.h>
@@ -84,8 +84,9 @@ static gmlnode* N;
 static gmledge* E;
 static Dt_t* L;
 static Dt_t** liststk;
-static int liststk_sz, liststk_cnt;
- 
+static int liststk_sz;
+static int liststk_cnt;
+
 static void free_attr (Dt_t*d, gmlattr* p, Dtdisc_t* ds); /* forward decl */
 static char* sortToStr (int sort);    /* forward decl */
 
@@ -325,8 +326,8 @@ setDir (char* d)
 }
 
 
-/* Line 336 of yacc.c  */
-#line 330 "y.tab.c"
+/* Line 371 of yacc.c  */
+#line 331 "y.tab.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -346,8 +347,8 @@ setDir (char* d)
 
 /* In a future release of Bison, this section will be replaced
    by #include "y.tab.h".  */
-#ifndef YY_Y_TAB_H
-# define YY_Y_TAB_H
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -435,8 +436,8 @@ extern int gmldebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-/* Line 350 of yacc.c  */
-#line 275 "../../cmd/tools/gmlparse.y"
+/* Line 387 of yacc.c  */
+#line 276 "../../cmd/tools/gmlparse.y"
 
     int i;
     char *str;
@@ -446,8 +447,8 @@ typedef union YYSTYPE
     Dt_t*    list;
 
 
-/* Line 350 of yacc.c  */
-#line 451 "y.tab.c"
+/* Line 387 of yacc.c  */
+#line 452 "y.tab.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define gmlstype YYSTYPE /* obsolescent; will be withdrawn */
@@ -470,12 +471,12 @@ int gmlparse ();
 #endif
 #endif /* ! YYPARSE_PARAM */
 
-#endif /* !YY_Y_TAB_H  */
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-/* Line 353 of yacc.c  */
-#line 479 "y.tab.c"
+/* Line 390 of yacc.c  */
+#line 480 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -528,24 +529,24 @@ typedef short int gmltype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -787,13 +788,13 @@ static const gmltype_int8 gmlrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const gmltype_uint16 gmlrline[] =
 {
-       0,   298,   298,   299,   300,   303,   306,   309,   310,   313,
-     314,   317,   318,   319,   320,   327,   328,   331,   331,   334,
-     335,   338,   339,   342,   342,   345,   346,   349,   350,   351,
-     352,   355,   355,   358,   359,   362,   363,   366,   367,   368,
-     369,   370,   371,   372,   373,   374,   375,   376,   377,   378,
-     379,   380,   381,   382,   383,   384,   385,   386,   387,   388,
-     389,   390,   391
+       0,   299,   299,   300,   301,   304,   307,   310,   311,   314,
+     315,   318,   319,   320,   321,   328,   329,   332,   332,   335,
+     336,   339,   340,   343,   343,   346,   347,   350,   351,   352,
+     353,   356,   356,   359,   360,   363,   364,   367,   368,   369,
+     370,   371,   372,   373,   374,   375,   376,   377,   378,   379,
+     380,   381,   382,   383,   384,   385,   386,   387,   388,   389,
+     390,   391,   392
 };
 #endif
 
@@ -930,10 +931,10 @@ static const gmltype_int8 gmltable[] =
       21,     0,     0,     0,     0,    22
 };
 
-#define gmlpact_value_is_default(gmlstate) \
-  ((gmlstate) == (-30))
+#define gmlpact_value_is_default(Yystate) \
+  (!!((Yystate) == (-30)))
 
-#define gmltable_value_is_error(gmltable_value) \
+#define gmltable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const gmltype_int8 gmlcheck[] =
@@ -1024,47 +1025,18 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
-    do                                                                  \
-      if (YYID (N))                                                     \
-        {                                                               \
-          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
-          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
-          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
-          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
-        }                                                               \
-      else                                                              \
-        {                                                               \
-          (Current).first_line   = (Current).last_line   =              \
-            YYRHSLOC (Rhs, 0).last_line;                                \
-          (Current).first_column = (Current).last_column =              \
-            YYRHSLOC (Rhs, 0).last_column;                              \
-        }                                                               \
-    while (YYID (0))
-#endif
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
-
-
 
 /* This macro is provided for backward compatibility. */
-
 #ifndef YY_LOCATION_PRINT
 # define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
 /* YYLEX -- calling `gmllex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX gmllex (YYLEX_PARAM)
 #else
@@ -1127,7 +1099,7 @@ gml_symbol_value_print (gmloutput, gmltype, gmlvaluep)
   switch (gmltype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1206,7 +1178,7 @@ gml_reduce_print (gmlvsp, gmlrule)
 {
   int gmlnrhs = gmlr2[gmlrule];
   int gmli;
-  unsigned long int gmllno = gmlrline[gmlrule];
+  uint64_t gmllno = gmlrline[gmlrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
 	     gmlrule - 1, gmllno);
   /* The symbols being reduced.  */
@@ -1369,7 +1341,6 @@ gmlsyntax_error (YYSIZE_T *gmlmsg_alloc, char **gmlmsg,
 {
   YYSIZE_T gmlsize0 = gmltnamerr (YY_NULL, gmltname[gmltoken]);
   YYSIZE_T gmlsize = gmlsize0;
-  YYSIZE_T gmlsize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *gmlformat = YY_NULL;
@@ -1432,11 +1403,13 @@ gmlsyntax_error (YYSIZE_T *gmlmsg_alloc, char **gmlmsg,
                     break;
                   }
                 gmlarg[gmlcount++] = gmltname[gmlx];
-                gmlsize1 = gmlsize + gmltnamerr (YY_NULL, gmltname[gmlx]);
-                if (! (gmlsize <= gmlsize1
-                       && gmlsize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                gmlsize = gmlsize1;
+                {
+                  YYSIZE_T gmlsize1 = gmlsize + gmltnamerr (YY_NULL, gmltname[gmlx]);
+                  if (! (gmlsize <= gmlsize1
+                         && gmlsize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  gmlsize = gmlsize1;
+                }
               }
         }
     }
@@ -1456,10 +1429,12 @@ gmlsyntax_error (YYSIZE_T *gmlmsg_alloc, char **gmlmsg,
 # undef YYCASE_
     }
 
-  gmlsize1 = gmlsize + gmlstrlen (gmlformat);
-  if (! (gmlsize <= gmlsize1 && gmlsize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  gmlsize = gmlsize1;
+  {
+    YYSIZE_T gmlsize1 = gmlsize + gmlstrlen (gmlformat);
+    if (! (gmlsize <= gmlsize1 && gmlsize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    gmlsize = gmlsize1;
+  }
 
   if (*gmlmsg_alloc < gmlsize)
     {
@@ -1519,7 +1494,7 @@ gmldestruct (gmlmsg, gmltype, gmlvaluep)
     {
 
       default:
-	break;
+        break;
     }
 }
 
@@ -1529,8 +1504,17 @@ gmldestruct (gmlmsg, gmltype, gmlvaluep)
 /* The lookahead symbol.  */
 int gmlchar;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE gmllval;
+YYSTYPE gmllval YY_INITIAL_VALUE(gmlval_default);
 
 /* Number of syntax errors so far.  */
 int gmlnerrs;
@@ -1588,7 +1572,7 @@ gmlparse ()
   int gmln;
   int gmlresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int gmltoken;
+  int gmltoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE gmlval;
@@ -1606,9 +1590,8 @@ gmlparse ()
      Keep to zero when no symbol should be popped.  */
   int gmllen = 0;
 
-  gmltoken = 0;
-  gmlss = gmlssa;
-  gmlvs = gmlvsa;
+  gmlssp = gmlss = gmlssa;
+  gmlvsp = gmlvs = gmlvsa;
   gmlstacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1617,13 +1600,6 @@ gmlparse ()
   gmlerrstatus = 0;
   gmlnerrs = 0;
   gmlchar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  gmlssp = gmlss;
-  gmlvsp = gmlvs;
   goto gmlsetstate;
 
 /*------------------------------------------------------------.
@@ -1692,7 +1668,7 @@ gmlparse ()
       gmlvsp = gmlvs + gmlsize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-		  (unsigned long int) gmlstacksize));
+		  (uint64_t) gmlstacksize));
 
       if (gmlss + gmlstacksize - 1 <= gmlssp)
 	YYABORT;
@@ -1764,7 +1740,9 @@ gmlbackup:
   gmlchar = YYEMPTY;
 
   gmlstate = gmln;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++gmlvsp = gmllval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   goto gmlnewstate;
 
@@ -1801,38 +1779,38 @@ gmlreduce:
   switch (gmln)
     {
         case 2:
-/* Line 1787 of yacc.c  */
-#line 298 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 299 "../../cmd/tools/gmlparse.y"
     {gmllexeof(); if (G->parent) popG(); }
     break;
 
   case 3:
-/* Line 1787 of yacc.c  */
-#line 299 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 300 "../../cmd/tools/gmlparse.y"
     { cleanup(); YYABORT; }
     break;
 
   case 5:
-/* Line 1787 of yacc.c  */
-#line 303 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 304 "../../cmd/tools/gmlparse.y"
     { pushG(); }
     break;
 
   case 11:
-/* Line 1787 of yacc.c  */
-#line 317 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 318 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->nodelist, (gmlvsp[(1) - (1)].np)); }
     break;
 
   case 12:
-/* Line 1787 of yacc.c  */
-#line 318 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 319 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->edgelist, (gmlvsp[(1) - (1)].ep)); }
     break;
 
   case 14:
-/* Line 1787 of yacc.c  */
-#line 320 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 321 "../../cmd/tools/gmlparse.y"
     { 
 		if (setDir((gmlvsp[(2) - (2)].str))) { 
 		    gmlerror("mixed directed and undirected graphs"); 
@@ -1843,260 +1821,260 @@ gmlreduce:
     break;
 
   case 15:
-/* Line 1787 of yacc.c  */
-#line 327 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 328 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->attrlist, mkAttr (strdup("id"), 0, INTEGER, (gmlvsp[(2) - (2)].str), 0)); }
     break;
 
   case 16:
-/* Line 1787 of yacc.c  */
-#line 328 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 329 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->attrlist, (gmlvsp[(1) - (1)].ap)); }
     break;
 
   case 17:
-/* Line 1787 of yacc.c  */
-#line 331 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 332 "../../cmd/tools/gmlparse.y"
     { N = mkNode(); }
     break;
 
   case 18:
-/* Line 1787 of yacc.c  */
-#line 331 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 332 "../../cmd/tools/gmlparse.y"
     { (gmlval.np) = N; N = NULL; }
     break;
 
   case 21:
-/* Line 1787 of yacc.c  */
-#line 338 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 339 "../../cmd/tools/gmlparse.y"
     { N->id = (gmlvsp[(2) - (2)].str); }
     break;
 
   case 22:
-/* Line 1787 of yacc.c  */
-#line 339 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 340 "../../cmd/tools/gmlparse.y"
     { dtinsert (N->attrlist, (gmlvsp[(1) - (1)].ap)); }
     break;
 
   case 23:
-/* Line 1787 of yacc.c  */
-#line 342 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 343 "../../cmd/tools/gmlparse.y"
     { E = mkEdge(); }
     break;
 
   case 24:
-/* Line 1787 of yacc.c  */
-#line 342 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 343 "../../cmd/tools/gmlparse.y"
     { (gmlval.ep) = E; E = NULL; }
     break;
 
   case 27:
-/* Line 1787 of yacc.c  */
-#line 349 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 350 "../../cmd/tools/gmlparse.y"
     { E->source = (gmlvsp[(2) - (2)].str); }
     break;
 
   case 28:
-/* Line 1787 of yacc.c  */
-#line 350 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 351 "../../cmd/tools/gmlparse.y"
     { E->target = (gmlvsp[(2) - (2)].str); }
     break;
 
   case 29:
-/* Line 1787 of yacc.c  */
-#line 351 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 352 "../../cmd/tools/gmlparse.y"
     { dtinsert (E->attrlist, mkAttr (strdup("id"), 0, INTEGER, (gmlvsp[(2) - (2)].str), 0)); }
     break;
 
   case 30:
-/* Line 1787 of yacc.c  */
-#line 352 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 353 "../../cmd/tools/gmlparse.y"
     { dtinsert (E->attrlist, (gmlvsp[(1) - (1)].ap)); }
     break;
 
   case 31:
-/* Line 1787 of yacc.c  */
-#line 355 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 356 "../../cmd/tools/gmlparse.y"
     {pushAlist(); }
     break;
 
   case 32:
-/* Line 1787 of yacc.c  */
-#line 355 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 356 "../../cmd/tools/gmlparse.y"
     { (gmlval.list) = popAlist(); }
     break;
 
   case 35:
-/* Line 1787 of yacc.c  */
-#line 362 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 363 "../../cmd/tools/gmlparse.y"
     { dtinsert (L, (gmlvsp[(2) - (2)].ap)); }
     break;
 
   case 36:
-/* Line 1787 of yacc.c  */
-#line 363 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 364 "../../cmd/tools/gmlparse.y"
     { dtinsert (L, (gmlvsp[(1) - (1)].ap)); }
     break;
 
   case 37:
-/* Line 1787 of yacc.c  */
-#line 366 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 367 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr ((gmlvsp[(1) - (2)].str), 0, INTEGER, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 38:
-/* Line 1787 of yacc.c  */
-#line 367 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 368 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr ((gmlvsp[(1) - (2)].str), 0, REAL, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 39:
-/* Line 1787 of yacc.c  */
-#line 368 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 369 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr ((gmlvsp[(1) - (2)].str), 0, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 40:
-/* Line 1787 of yacc.c  */
-#line 369 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 370 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr ((gmlvsp[(1) - (2)].str), 0, LIST, 0, (gmlvsp[(2) - (2)].list)); }
     break;
 
   case 41:
-/* Line 1787 of yacc.c  */
-#line 370 "../../cmd/tools/gmlparse.y"
-    { (gmlval.ap) = mkAttr (0, XVAL, REAL, (gmlvsp[(2) - (2)].str), 0); }
-    break;
-
-  case 42:
-/* Line 1787 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 371 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, XVAL, REAL, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
-  case 43:
-/* Line 1787 of yacc.c  */
+  case 42:
+/* Line 1792 of yacc.c  */
 #line 372 "../../cmd/tools/gmlparse.y"
+    { (gmlval.ap) = mkAttr (0, XVAL, REAL, (gmlvsp[(2) - (2)].str), 0); }
+    break;
+
+  case 43:
+/* Line 1792 of yacc.c  */
+#line 373 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, YVAL, REAL, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 44:
-/* Line 1787 of yacc.c  */
-#line 373 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 374 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, WVAL, REAL, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 45:
-/* Line 1787 of yacc.c  */
-#line 374 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 375 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, HVAL, REAL, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 46:
-/* Line 1787 of yacc.c  */
-#line 375 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 376 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, LABEL, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 47:
-/* Line 1787 of yacc.c  */
-#line 376 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 377 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, GRAPHICS, LIST, 0, (gmlvsp[(2) - (2)].list)); }
     break;
 
   case 48:
-/* Line 1787 of yacc.c  */
-#line 377 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 378 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, LABELGRAPHICS, LIST, 0, (gmlvsp[(2) - (2)].list)); }
     break;
 
   case 49:
-/* Line 1787 of yacc.c  */
-#line 378 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 379 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, TYPE, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 50:
-/* Line 1787 of yacc.c  */
-#line 379 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 380 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, FILL, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 51:
-/* Line 1787 of yacc.c  */
-#line 380 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 381 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, OUTLINE, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 52:
-/* Line 1787 of yacc.c  */
-#line 381 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 382 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, OUTLINESTYLE, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 53:
-/* Line 1787 of yacc.c  */
-#line 382 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 383 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, OUTLINEWIDTH, INTEGER, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 54:
-/* Line 1787 of yacc.c  */
-#line 383 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 384 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, OUTLINEWIDTH, REAL, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 55:
-/* Line 1787 of yacc.c  */
-#line 384 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 385 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, STYLE, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 56:
-/* Line 1787 of yacc.c  */
-#line 385 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 386 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, STYLE, LIST, 0, (gmlvsp[(2) - (2)].list)); }
     break;
 
   case 57:
-/* Line 1787 of yacc.c  */
-#line 386 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 387 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, LINE, LIST, 0, (gmlvsp[(2) - (2)].list)); }
     break;
 
   case 58:
-/* Line 1787 of yacc.c  */
-#line 387 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 388 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, POINT, LIST, 0, (gmlvsp[(2) - (2)].list)); }
     break;
 
   case 59:
-/* Line 1787 of yacc.c  */
-#line 388 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 389 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, TEXT, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 60:
-/* Line 1787 of yacc.c  */
-#line 389 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 390 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, FONTNAME, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 61:
-/* Line 1787 of yacc.c  */
-#line 390 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 391 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, FONTNAME, INTEGER, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
   case 62:
-/* Line 1787 of yacc.c  */
-#line 391 "../../cmd/tools/gmlparse.y"
+/* Line 1792 of yacc.c  */
+#line 392 "../../cmd/tools/gmlparse.y"
     { (gmlval.ap) = mkAttr (0, COLOR, STRING, (gmlvsp[(2) - (2)].str), 0); }
     break;
 
 
-/* Line 1787 of yacc.c  */
-#line 2100 "y.tab.c"
+/* Line 1792 of yacc.c  */
+#line 2078 "y.tab.c"
       default: break;
     }
   /* User semantic actions sometimes alter gmlchar, and that requires
@@ -2259,7 +2237,9 @@ gmlerrlab1:
       YY_STACK_PRINT (gmlss, gmlssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++gmlvsp = gmllval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
 
   /* Shift the error token.  */
@@ -2325,8 +2305,8 @@ gmlreturn:
 }
 
 
-/* Line 2048 of yacc.c  */
-#line 394 "../../cmd/tools/gmlparse.y"
+/* Line 2055 of yacc.c  */
+#line 395 "../../cmd/tools/gmlparse.y"
 
 
 static void
@@ -2851,4 +2831,3 @@ int gmllex ()
 }
 #endif
 
-
