@@ -84,8 +84,9 @@ static gmlnode* N;
 static gmledge* E;
 static Dt_t* L;
 static Dt_t** liststk;
-static int liststk_sz, liststk_cnt;
- 
+static int liststk_sz;
+static int liststk_cnt;
+
 static void free_attr (Dt_t*d, gmlattr* p, Dtdisc_t* ds); /* forward decl */
 static char* sortToStr (int sort);    /* forward decl */
 
@@ -326,7 +327,7 @@ setDir (char* d)
 
 
 /* Line 371 of yacc.c  */
-#line 330 "y.tab.c"
+#line 331 "y.tab.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -436,7 +437,7 @@ extern int yydebug;
 typedef union YYSTYPE
 {
 /* Line 387 of yacc.c  */
-#line 275 "../../cmd/tools/gmlparse.y"
+#line 276 "../../cmd/tools/gmlparse.y"
 
     int i;
     char *str;
@@ -447,7 +448,7 @@ typedef union YYSTYPE
 
 
 /* Line 387 of yacc.c  */
-#line 451 "y.tab.c"
+#line 452 "y.tab.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -475,7 +476,7 @@ int yyparse ();
 /* Copy the second part of user declarations.  */
 
 /* Line 390 of yacc.c  */
-#line 479 "y.tab.c"
+#line 480 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -787,13 +788,13 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   298,   298,   299,   300,   303,   306,   309,   310,   313,
-     314,   317,   318,   319,   320,   327,   328,   331,   331,   334,
-     335,   338,   339,   342,   342,   345,   346,   349,   350,   351,
-     352,   355,   355,   358,   359,   362,   363,   366,   367,   368,
-     369,   370,   371,   372,   373,   374,   375,   376,   377,   378,
-     379,   380,   381,   382,   383,   384,   385,   386,   387,   388,
-     389,   390,   391
+       0,   299,   299,   300,   301,   304,   307,   310,   311,   314,
+     315,   318,   319,   320,   321,   328,   329,   332,   332,   335,
+     336,   339,   340,   343,   343,   346,   347,   350,   351,   352,
+     353,   356,   356,   359,   360,   363,   364,   367,   368,   369,
+     370,   371,   372,   373,   374,   375,   376,   377,   378,   379,
+     380,   381,   382,   383,   384,   385,   386,   387,   388,   389,
+     390,   391,   392
 };
 #endif
 
@@ -1779,37 +1780,37 @@ yyreduce:
     {
         case 2:
 /* Line 1792 of yacc.c  */
-#line 298 "../../cmd/tools/gmlparse.y"
+#line 299 "../../cmd/tools/gmlparse.y"
     {gmllexeof(); if (G->parent) popG(); }
     break;
 
   case 3:
 /* Line 1792 of yacc.c  */
-#line 299 "../../cmd/tools/gmlparse.y"
+#line 300 "../../cmd/tools/gmlparse.y"
     { cleanup(); YYABORT; }
     break;
 
   case 5:
 /* Line 1792 of yacc.c  */
-#line 303 "../../cmd/tools/gmlparse.y"
+#line 304 "../../cmd/tools/gmlparse.y"
     { pushG(); }
     break;
 
   case 11:
 /* Line 1792 of yacc.c  */
-#line 317 "../../cmd/tools/gmlparse.y"
+#line 318 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->nodelist, (yyvsp[(1) - (1)].np)); }
     break;
 
   case 12:
 /* Line 1792 of yacc.c  */
-#line 318 "../../cmd/tools/gmlparse.y"
+#line 319 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->edgelist, (yyvsp[(1) - (1)].ep)); }
     break;
 
   case 14:
 /* Line 1792 of yacc.c  */
-#line 320 "../../cmd/tools/gmlparse.y"
+#line 321 "../../cmd/tools/gmlparse.y"
     { 
 		if (setDir((yyvsp[(2) - (2)].str))) { 
 		    yyerror("mixed directed and undirected graphs"); 
@@ -1821,259 +1822,259 @@ yyreduce:
 
   case 15:
 /* Line 1792 of yacc.c  */
-#line 327 "../../cmd/tools/gmlparse.y"
+#line 328 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->attrlist, mkAttr (strdup("id"), 0, INTEGER, (yyvsp[(2) - (2)].str), 0)); }
     break;
 
   case 16:
 /* Line 1792 of yacc.c  */
-#line 328 "../../cmd/tools/gmlparse.y"
+#line 329 "../../cmd/tools/gmlparse.y"
     { dtinsert (G->attrlist, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 17:
 /* Line 1792 of yacc.c  */
-#line 331 "../../cmd/tools/gmlparse.y"
+#line 332 "../../cmd/tools/gmlparse.y"
     { N = mkNode(); }
     break;
 
   case 18:
 /* Line 1792 of yacc.c  */
-#line 331 "../../cmd/tools/gmlparse.y"
+#line 332 "../../cmd/tools/gmlparse.y"
     { (yyval.np) = N; N = NULL; }
     break;
 
   case 21:
 /* Line 1792 of yacc.c  */
-#line 338 "../../cmd/tools/gmlparse.y"
+#line 339 "../../cmd/tools/gmlparse.y"
     { N->id = (yyvsp[(2) - (2)].str); }
     break;
 
   case 22:
 /* Line 1792 of yacc.c  */
-#line 339 "../../cmd/tools/gmlparse.y"
+#line 340 "../../cmd/tools/gmlparse.y"
     { dtinsert (N->attrlist, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 23:
 /* Line 1792 of yacc.c  */
-#line 342 "../../cmd/tools/gmlparse.y"
+#line 343 "../../cmd/tools/gmlparse.y"
     { E = mkEdge(); }
     break;
 
   case 24:
 /* Line 1792 of yacc.c  */
-#line 342 "../../cmd/tools/gmlparse.y"
+#line 343 "../../cmd/tools/gmlparse.y"
     { (yyval.ep) = E; E = NULL; }
     break;
 
   case 27:
 /* Line 1792 of yacc.c  */
-#line 349 "../../cmd/tools/gmlparse.y"
+#line 350 "../../cmd/tools/gmlparse.y"
     { E->source = (yyvsp[(2) - (2)].str); }
     break;
 
   case 28:
 /* Line 1792 of yacc.c  */
-#line 350 "../../cmd/tools/gmlparse.y"
+#line 351 "../../cmd/tools/gmlparse.y"
     { E->target = (yyvsp[(2) - (2)].str); }
     break;
 
   case 29:
 /* Line 1792 of yacc.c  */
-#line 351 "../../cmd/tools/gmlparse.y"
+#line 352 "../../cmd/tools/gmlparse.y"
     { dtinsert (E->attrlist, mkAttr (strdup("id"), 0, INTEGER, (yyvsp[(2) - (2)].str), 0)); }
     break;
 
   case 30:
 /* Line 1792 of yacc.c  */
-#line 352 "../../cmd/tools/gmlparse.y"
+#line 353 "../../cmd/tools/gmlparse.y"
     { dtinsert (E->attrlist, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 31:
 /* Line 1792 of yacc.c  */
-#line 355 "../../cmd/tools/gmlparse.y"
+#line 356 "../../cmd/tools/gmlparse.y"
     {pushAlist(); }
     break;
 
   case 32:
 /* Line 1792 of yacc.c  */
-#line 355 "../../cmd/tools/gmlparse.y"
+#line 356 "../../cmd/tools/gmlparse.y"
     { (yyval.list) = popAlist(); }
     break;
 
   case 35:
 /* Line 1792 of yacc.c  */
-#line 362 "../../cmd/tools/gmlparse.y"
+#line 363 "../../cmd/tools/gmlparse.y"
     { dtinsert (L, (yyvsp[(2) - (2)].ap)); }
     break;
 
   case 36:
 /* Line 1792 of yacc.c  */
-#line 363 "../../cmd/tools/gmlparse.y"
+#line 364 "../../cmd/tools/gmlparse.y"
     { dtinsert (L, (yyvsp[(1) - (1)].ap)); }
     break;
 
   case 37:
 /* Line 1792 of yacc.c  */
-#line 366 "../../cmd/tools/gmlparse.y"
+#line 367 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, INTEGER, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 38:
 /* Line 1792 of yacc.c  */
-#line 367 "../../cmd/tools/gmlparse.y"
+#line 368 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 39:
 /* Line 1792 of yacc.c  */
-#line 368 "../../cmd/tools/gmlparse.y"
+#line 369 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 40:
 /* Line 1792 of yacc.c  */
-#line 369 "../../cmd/tools/gmlparse.y"
+#line 370 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr ((yyvsp[(1) - (2)].str), 0, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 41:
 /* Line 1792 of yacc.c  */
-#line 370 "../../cmd/tools/gmlparse.y"
+#line 371 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, XVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 42:
 /* Line 1792 of yacc.c  */
-#line 371 "../../cmd/tools/gmlparse.y"
+#line 372 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, XVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 43:
 /* Line 1792 of yacc.c  */
-#line 372 "../../cmd/tools/gmlparse.y"
+#line 373 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, YVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 44:
 /* Line 1792 of yacc.c  */
-#line 373 "../../cmd/tools/gmlparse.y"
+#line 374 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, WVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 45:
 /* Line 1792 of yacc.c  */
-#line 374 "../../cmd/tools/gmlparse.y"
+#line 375 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, HVAL, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 46:
 /* Line 1792 of yacc.c  */
-#line 375 "../../cmd/tools/gmlparse.y"
+#line 376 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, LABEL, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 47:
 /* Line 1792 of yacc.c  */
-#line 376 "../../cmd/tools/gmlparse.y"
+#line 377 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, GRAPHICS, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 48:
 /* Line 1792 of yacc.c  */
-#line 377 "../../cmd/tools/gmlparse.y"
+#line 378 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, LABELGRAPHICS, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 49:
 /* Line 1792 of yacc.c  */
-#line 378 "../../cmd/tools/gmlparse.y"
+#line 379 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, TYPE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 50:
 /* Line 1792 of yacc.c  */
-#line 379 "../../cmd/tools/gmlparse.y"
+#line 380 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, FILL, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 51:
 /* Line 1792 of yacc.c  */
-#line 380 "../../cmd/tools/gmlparse.y"
+#line 381 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 52:
 /* Line 1792 of yacc.c  */
-#line 381 "../../cmd/tools/gmlparse.y"
+#line 382 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINESTYLE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 53:
 /* Line 1792 of yacc.c  */
-#line 382 "../../cmd/tools/gmlparse.y"
+#line 383 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINEWIDTH, INTEGER, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 54:
 /* Line 1792 of yacc.c  */
-#line 383 "../../cmd/tools/gmlparse.y"
+#line 384 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, OUTLINEWIDTH, REAL, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 55:
 /* Line 1792 of yacc.c  */
-#line 384 "../../cmd/tools/gmlparse.y"
+#line 385 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, STYLE, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 56:
 /* Line 1792 of yacc.c  */
-#line 385 "../../cmd/tools/gmlparse.y"
+#line 386 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, STYLE, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 57:
 /* Line 1792 of yacc.c  */
-#line 386 "../../cmd/tools/gmlparse.y"
+#line 387 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, LINE, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 58:
 /* Line 1792 of yacc.c  */
-#line 387 "../../cmd/tools/gmlparse.y"
+#line 388 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, POINT, LIST, 0, (yyvsp[(2) - (2)].list)); }
     break;
 
   case 59:
 /* Line 1792 of yacc.c  */
-#line 388 "../../cmd/tools/gmlparse.y"
+#line 389 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, TEXT, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 60:
 /* Line 1792 of yacc.c  */
-#line 389 "../../cmd/tools/gmlparse.y"
+#line 390 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, FONTNAME, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 61:
 /* Line 1792 of yacc.c  */
-#line 390 "../../cmd/tools/gmlparse.y"
+#line 391 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, FONTNAME, INTEGER, (yyvsp[(2) - (2)].str), 0); }
     break;
 
   case 62:
 /* Line 1792 of yacc.c  */
-#line 391 "../../cmd/tools/gmlparse.y"
+#line 392 "../../cmd/tools/gmlparse.y"
     { (yyval.ap) = mkAttr (0, COLOR, STRING, (yyvsp[(2) - (2)].str), 0); }
     break;
 
 
 /* Line 1792 of yacc.c  */
-#line 2077 "y.tab.c"
+#line 2078 "y.tab.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2305,7 +2306,7 @@ yyreturn:
 
 
 /* Line 2055 of yacc.c  */
-#line 394 "../../cmd/tools/gmlparse.y"
+#line 395 "../../cmd/tools/gmlparse.y"
 
 
 static void
