@@ -2,7 +2,7 @@
 #define GVPLUGIN_VERSION 6
 #define PACKAGE_BUGREPORT "http://www.graphviz.org/"
 #define PACKAGE_NAME "graphviz"
-#define PACKAGE_STRING "graphviz 2.36.0"
+#define PACKAGE_STRING "graphviz 2.41.20171026.1811"
 #define PACKAGE_TARNAME "graphviz"
 #define PACKAGE_URL ""
-#define PACKAGE_VERSION "2.36.0"
+#define PACKAGE_VERSION "2.41.20171026.1811"
