@@ -622,7 +622,7 @@ static void emit_html_img(GVJ_t * job, htmlimg_t * cp, htmlenv_t * env)
 	scale = env->imgscale;
     assert(cp->src);
     assert(cp->src[0]);
-    gvrender_usershape(job, cp->src, A, 4, TRUE, scale);
+    gvrender_usershape(job, cp->src, A, 4, TRUE, scale, "mc");
 }
 
 static void emit_html_cell(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env)
@@ -1322,7 +1322,7 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
 }
 
 /* Split size x over n pieces with spacing s.
- * We substract s*(n-1) from x, divide by n and 
+ * We subtract s*(n-1) from x, divide by n and 
  * take the ceiling.
  */
 #define SPLIT(x,n,s) (((x) - ((s)-1)*((n)-1)) / (n))
