@@ -484,6 +484,7 @@ subtree_t *merge_trees(Agedge_t *e)   /* entering tree edge */
 /* Construct initial tight tree. Graph must be connected, feasible.
  * Adjust ND_rank(v) as needed.  add_tree_edge() on tight tree edges.
  * trees are basically lists of nodes stored in nodequeues.
+ * Return 1 if input graph is not connected; 0 on success.
  */
 static
 int feasible_tree(void)
@@ -493,6 +494,7 @@ int feasible_tree(void)
   subtree_t **tree, *tree0, *tree1;
   int i, subtree_count = 0;
   STheap_t *heap;
+  int error = 0;
 
   /* initialization */
   for (n = GD_nlist(G); n; n = ND_next(n)) {
@@ -512,7 +514,10 @@ int feasible_tree(void)
   heap = STbuildheap(tree,subtree_count);
   while (STheapsize(heap) > 1) {
     tree0 = STextractmin(heap);
-    ee = inter_tree_edge(tree0);
+    if (!(ee = inter_tree_edge(tree0))) {
+      error = 1;
+      break;
+    }
     tree1 = merge_trees(ee);
     STheapify(heap,tree1->heap_index);
   }
@@ -520,6 +525,7 @@ int feasible_tree(void)
   free(heap);
   for (i = 0; i < subtree_count; i++) free(tree[i]);
   free(tree);
+  if (error) return 1;
   assert(Tree_edge.size == N_nodes - 1);
   init_cutvalues();
   return 0;
@@ -782,7 +788,7 @@ graphSize (graph_t * g, int* nn, int* ne)
  *   Out and in edges lists stored in ND_out and ND_in, even if the node
  *  doesn't have any out or in edges.
  * The node rank values are stored in ND_rank.
- * Returns 0 if successful; returns 1 if `he graph was not connected;
+ * Returns 0 if successful; returns 1 if the graph was not connected;
  * returns 2 if something seriously wrong;
  */
 int rank2(graph_t * g, int balance, int maxiter, int search_size)
