@@ -143,7 +143,10 @@ extern "C" {
 	int fontrenaming;
     };
 
-#ifdef WIN32
+extern GVC_t* gvCloneGVC (GVC_t *);
+extern void gvFreeCloneGVC (GVC_t *);
+
+#ifdef _WIN32
 #define DIRSEP "\\"
 #else
 #define DIRSEP "/"
