@@ -585,7 +585,7 @@ int deleteObj(Agraph_t * g, Agobj_t * obj)
  */
 int sfioWrite(Agraph_t * g, Sfio_t* fp, Agiodisc_t* dfltDisc)
 {
-    Agiodisc_t* saveio;
+    Agiodisc_t* saveio = NULL;
     int rv;
 
     if (g->clos->disc.io != dfltDisc) {
@@ -813,7 +813,7 @@ char *canon(Expr_t * pgm, char *arg)
 }
 
 #include <stdlib.h>
-#ifdef WIN32
+#ifdef _WIN32
 #include "compat.h"
 #endif
 
@@ -823,7 +823,7 @@ char *canon(Expr_t * pgm, char *arg)
 
 static char* colorscheme;
 
-#ifdef WIN32
+#ifdef _MSC_VER
 extern int strcasecmp(const char *s1, const char *s2);
 extern int strncasecmp(const char *s1, const char *s2, unsigned int n);
 #endif
@@ -1285,7 +1285,7 @@ int colorxlate(char *str, gvcolor_t * color, color_type_t target_type)
  */
 char *colorx (Expr_t* ex, char* incolor, char* fmt, Sfio_t* fp)
 {
-    gvcolor_t color;
+    gvcolor_t color = {{{0}},0};
     color_type_t type;
     int rc;
     int alpha;
@@ -1340,7 +1340,7 @@ char *colorx (Expr_t* ex, char* incolor, char* fmt, Sfio_t* fp)
     return exstring(ex, sfstruse(fp));
 }
 
-#ifndef WIN32
+#ifndef _WIN32
 
 #include        <unistd.h>
 #include        <sys/types.h>
