@@ -67,7 +67,7 @@ static int ioflush(void *chan)
 
 static Agiodisc_t gprIoDisc = { iofread, ioputstr, ioflush };
 
-#ifdef WIN32
+#ifdef _WIN32
 static Agdisc_t gprDisc = { 0, 0, &gprIoDisc };
 #else
 static Agdisc_t gprDisc = { &AgMemDisc, &AgIdDisc, &gprIoDisc };
@@ -1501,6 +1501,7 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 		v.integer = -1;
 	    break;
 	default:
+		v.integer = -1;
 	    exerror("unknown function call: %s", sym->name);
 	}
 	return v;
@@ -2592,7 +2593,7 @@ Agraph_t *readG(Sfio_t * fp)
 {
     Agraph_t *g;
 
-#ifdef WIN32
+#ifdef _WIN32
     gprDisc.mem = &AgMemDisc;
     gprDisc.id = &AgIdDisc;
 #endif
@@ -2612,7 +2613,7 @@ Agraph_t *openG(char *name, Agdesc_t desc)
 {
     Agraph_t *g;
 
-#ifdef WIN32
+#ifdef _WIN32
     gprDisc.mem = &AgMemDisc;
     gprDisc.id = &AgIdDisc;
 #endif
