@@ -12,16 +12,8 @@
  *************************************************************************/
 
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-#ifdef HAVE_LIMITS_H
 #include <limits.h>
-#else
-#ifdef HAVE_VALUES_H
-#include <values.h>
-#endif
-#endif
 #include <sfdp.h>
 #include <neato.h>
 #include <adjust.h>
@@ -347,7 +339,7 @@ void sfdp_layout(graph_t * g)
 #endif
 
 	if ((am.mode == AM_PRISM) && doAdjust) {
-	    doAdjust = 0;  /* overlap removal done in sfpd */
+	    doAdjust = 0;  /* overlap removal done in sfdp */
 	    ctrl->overlap = am.value;
     	    ctrl->initial_scaling = am.scaling;
 	    sep = sepFactor(g);
@@ -364,6 +356,9 @@ void sfdp_layout(graph_t * g)
 	    ctrl->overlap = -1;
 	}
 
+	if (Verbose)
+	    spring_electrical_control_print(ctrl);
+
 	ccs = ccomps(g, &ncc, 0);
 	if (ncc == 1) {
 	    sfdpLayout(g, ctrl, hops, pad);
