@@ -13,18 +13,14 @@
 
 #include	"sfhdr.h"
 
+#include <float.h>
+
 /*	Write out a floating point value in a portable format
 **
 **	Written by Kiem-Phong Vo.
 */
 
-#if __STD_C
 int _sfputd(Sfio_t * f, Sfdouble_t v)
-#else
-int _sfputd(f, v)
-Sfio_t *f;
-Sfdouble_t v;
-#endif
 {
 #define N_ARRAY		(16*sizeof(Sfdouble_t))
     reg ssize_t n, w;
@@ -46,13 +42,6 @@ Sfdouble_t v;
     } else
 	n = 0;
 
-#if !_ast_fltmax_double		/* don't know how to do these yet */
-    if (v > SF_MAXDOUBLE && !_has_expfuncs) {
-	SFOPEN(f, 0);
-	SFMTXRETURN(f, -1);
-    }
-#endif
-
     /* make the magnitude of v < 1 */
     if (v != 0.)
 	v = frexp(v, &exp);
@@ -87,7 +76,7 @@ Sfdouble_t v;
 
     /* write out coded bytes */
     n = ends - s + 1;
-    w = SFWRITE(f, (Void_t *) s, n) == n ? w + n : -1;
+    w = SFWRITE(f, (void *) s, n) == n ? w + n : -1;
 
     SFOPEN(f, 0);
     SFMTXRETURN(f, w);
